@@ -6,6 +6,7 @@
 import json
 import sys
 from subprocess import PIPE, Popen
+from typing import Any, Dict
 
 import jupyter_client
 from jupyter_client import write_connection_file
@@ -56,6 +57,7 @@ def get_connection_info(connection_file=None, unpack=False):
 
         If unspecified, the connection file for the currently running
         IPython Kernel will be used, which is only allowed from inside a kernel.
+
     unpack : bool [default: False]
         if True, return the unpacked dict, otherwise just the string contents
         of the file.
@@ -68,13 +70,15 @@ def get_connection_info(connection_file=None, unpack=False):
     cf = _find_connection_file(connection_file)
 
     with open(cf) as f:
-        info = f.read()
+        info_str = f.read()
 
     if unpack:
-        info = json.loads(info)
+        info = json.loads(info_str)
         # ensure key is bytes:
         info["key"] = info.get("key", "").encode()
-    return info
+        return info
+
+    return info_str
 
 
 def connect_qtconsole(connection_file=None, argv=None):
@@ -92,6 +96,7 @@ def connect_qtconsole(connection_file=None, argv=None):
 
         If unspecified, the connection file for the currently running
         IPython Kernel will be used, which is only allowed from inside a kernel.
+
     argv : list [optional]
         Any extra args to be passed to the console.
 
@@ -103,9 +108,9 @@ def connect_qtconsole(connection_file=None, argv=None):
 
     cf = _find_connection_file(connection_file)
 
-    cmd = ";".join(["from IPython.qt.console import qtconsoleapp", "qtconsoleapp.main()"])
+    cmd = ";".join(["from qtconsole import qtconsoleapp", "qtconsoleapp.main()"])
 
-    kwargs = {}
+    kwargs: Dict[str, Any] = {}
     # Launch the Qt console in a separate session & process group, so
     # interrupting the kernel doesn't kill it.
     kwargs["start_new_session"] = True
