@@ -3,10 +3,10 @@
 # Copyright (c) IPython Development Team.
 # Distributed under the terms of the Modified BSD License.
 
-from traitlets import Instance, DottedObjectName, default
-from jupyter_client.managerabc import KernelManagerABC
 from jupyter_client.manager import KernelManager
+from jupyter_client.managerabc import KernelManagerABC
 from jupyter_client.session import Session
+from traitlets import DottedObjectName, Instance, default
 
 from .constants import INPROCESS_KEY
 
@@ -22,27 +22,28 @@ class InProcessKernelManager(KernelManager):
     """
 
     # The kernel process with which the KernelManager is communicating.
-    kernel = Instance('ipykernel.inprocess.ipkernel.InProcessKernel',
-                      allow_none=True)
+    kernel = Instance("ipykernel.inprocess.ipkernel.InProcessKernel", allow_none=True)
     # the client class for KM.client() shortcut
-    client_class = DottedObjectName('ipykernel.inprocess.BlockingInProcessKernelClient')
+    client_class = DottedObjectName("ipykernel.inprocess.BlockingInProcessKernelClient")
 
-    @default('blocking_class')
+    @default("blocking_class")
     def _default_blocking_class(self):
         from .blocking import BlockingInProcessKernelClient
+
         return BlockingInProcessKernelClient
 
-    @default('session')
+    @default("session")
     def _default_session(self):
         # don't sign in-process messages
         return Session(key=INPROCESS_KEY, parent=self)
 
-    #--------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
     # Kernel management methods
-    #--------------------------------------------------------------------------
+    # --------------------------------------------------------------------------
 
     def start_kernel(self, **kwds):
         from ipykernel.inprocess.ipkernel import InProcessKernel
+
         self.kernel = InProcessKernel(parent=self, session=self.session)
 
     def shutdown_kernel(self):
@@ -70,12 +71,12 @@ class InProcessKernelManager(KernelManager):
         return self.kernel is not None
 
     def client(self, **kwargs):
-        kwargs['kernel'] = self.kernel
+        kwargs["kernel"] = self.kernel
         return super().client(**kwargs)
 
 
-#-----------------------------------------------------------------------------
+# -----------------------------------------------------------------------------
 # ABC Registration
-#-----------------------------------------------------------------------------
+# -----------------------------------------------------------------------------
 
 KernelManagerABC.register(InProcessKernelManager)
